==> tcell_agent-0.2.32.tar.gz: tcell_agent-0.2.32/tcell_agent/tests/appsensor/sensors/database_sensor_test.py <==
import unittest

from mock import patch
from tcell_agent.appsensor.meta import AppSensorMeta
from tcell_agent.appsensor.sensors import DatabaseSensor


class DatabaseSensorTest(unittest.TestCase):
    def create_default_sensor_test(self):
        sensor = DatabaseSensor()
        self.assertEqual(sensor.enabled, False)
        self.assertEqual(sensor.max_rows, 1001)
        self.assertEqual(sensor.excluded_route_ids, set())

    def create_enabled_sensor_test(self):
        sensor = DatabaseSensor({"enabled": True})
        self.assertEqual(sensor.enabled, True)
        self.assertEqual(sensor.max_rows, 1001)
        self.assertEqual(sensor.excluded_route_ids, set())

    def create_sensor_with_max_rows_test(self):
        sensor = DatabaseSensor({"large_result": {"limit": 1024}})
        self.assertEqual(sensor.enabled, False)
        self.assertEqual(sensor.max_rows, 1024)
        self.assertEqual(sensor.excluded_route_ids, set())

    def create_sensor_with_exclude_routes_test(self):
        sensor = DatabaseSensor({"exclude_routes": ["1", "10", "20"]})
        self.assertEqual(sensor.enabled, False)
        self.assertEqual(sensor.max_rows, 1001)
        self.assertEqual(sensor.excluded_route_ids, set(["1", "10", "20"]))

    def with_disabled_sensor_should_check_test(self):
        sensor = DatabaseSensor({"enabled": False})
        self.assertFalse(sensor.should_check(None))

    def with_enabled_sensor_and_excluded_routes_will_check_test(self):
        sensor = DatabaseSensor({"enabled": True, "exclude_routes": ["1", "10", "20"]})
        self.assertFalse(sensor.should_check("1"))
        self.assertTrue(sensor.should_check(None))

    def with_disabled_sensor_check_test(self):
        sensor = DatabaseSensor({"enabled": False, "large_result": {"limit": 1024}})
        appsensor_meta = AppSensorMeta()
        appsensor_meta.remote_address = "remote_addr"
        appsensor_meta.method = "request_method"
        appsensor_meta.location = "abosolute_uri"
        appsensor_meta.route_id = "route_id"
        appsensor_meta.session_id = "session_id"
        appsensor_meta.user_id = "user_id"

        with patch('tcell_agent.appsensor.sensors.database_sensor.send_event') as patched_send_event:
            sensor.check(appsensor_meta, 3072)
            self.assertFalse(patched_send_event.called)

    def with_enabled_sensor_and_number_of_records_is_too_big_but_route_id_is_excluded_check_test(self):
        sensor = DatabaseSensor({"enabled": True, "large_result": {"limit": 1024}, "exclude_routes": ["23947"]})
        appsensor_meta = AppSensorMeta()
        appsensor_meta.remote_address = "remote_addr"
        appsensor_meta.method = "request_method"
        appsensor_meta.location = "abosolute_uri"
        appsensor_meta.route_id = "23947"
        appsensor_meta.session_id = "session_id"
        appsensor_meta.user_id = "user_id"

        with patch('tcell_agent.appsensor.sensors.database_sensor.send_event') as patched_send_event:
            sensor.check(appsensor_meta, 2048)
            self.assertFalse(patched_send_event.called)

    def with_enabled_sensor_and_number_of_records_is_ok_check_test(self):
        sensor = DatabaseSensor({"enabled": True, "large_result": {"limit": 1024}})
        appsensor_meta = AppSensorMeta()
        appsensor_meta.remote_address = "remote_addr"
        appsensor_meta.method = "request_method"
        appsensor_meta.location = "abosolute_uri"
        appsensor_meta.route_id = "route_id"
        appsensor_meta.session_id = "session_id"
        appsensor_meta.user_id = "user_id"

        with patch('tcell_agent.appsensor.sensors.database_sensor.send_event') as patched_send_event:
            sensor.check(appsensor_meta, 10)
            self.assertFalse(patched_send_event.called)

    def with_enabled_sensor_and_number_of_records_is_too_big_check_test(self):
        appsensor_meta = AppSensorMeta()
        appsensor_meta.remote_address = "remote_addr"
        appsensor_meta.method = "request_method"
        appsensor_meta.location = "abosolute_uri"
        appsensor_meta.route_id = "route_id"
        appsensor_meta.session_id = "session_id"
        appsensor_meta.user_id = "user_id"

        sensor = DatabaseSensor({"enabled": True, "large_result": {"limit": 1024}})

        with patch('tcell_agent.appsensor.sensors.database_sensor.send_event') as patched_send_event:
            sensor.check(appsensor_meta, 3072)
            patched_send_event.assert_called_once_with(appsensor_meta, DatabaseSensor.DP_CODE, None, {"rows": 3072})

==> tcell_agent-0.2.35.tar.gz: tcell_agent-0.2.35/tcell_agent/tests/appsensor/sensors/database_sensor_test.py <==
import unittest

from mock import patch
from tcell_agent.appsensor.meta import AppSensorMeta
from tcell_agent.appsensor.sensors import DatabaseSensor


class DatabaseSensorTest(unittest.TestCase):
    def create_default_sensor_test(self):
        sensor = DatabaseSensor()
        self.assertEqual(sensor.enabled, False)
        self.assertEqual(sensor.max_rows, 1001)
        self.assertEqual(sensor.excluded_route_ids, set())

    def create_enabled_sensor_test(self):
        sensor = DatabaseSensor({"enabled": True})
        self.assertEqual(sensor.enabled, True)
        self.assertEqual(sensor.max_rows, 1001)
        self.assertEqual(sensor.excluded_route_ids, set())

    def create_sensor_with_max_rows_test(self):
        sensor = DatabaseSensor({"large_result": {"limit": 1024}})
        self.assertEqual(sensor.enabled, False)
        self.assertEqual(sensor.max_rows, 1024)
        self.assertEqual(sensor.excluded_route_ids, set())

    def create_sensor_with_exclude_routes_test(self):
        sensor = DatabaseSensor({"exclude_routes": ["1", "10", "20"]})
        self.assertEqual(sensor.enabled, False)
        self.assertEqual(sensor.max_rows, 1001)
        self.assertEqual(sensor.excluded_route_ids, set(["1", "10", "20"]))

    def with_disabled_sensor_should_check_test(self):
        sensor = DatabaseSensor({"enabled": False})
        self.assertFalse(sensor.should_check(None))

    def with_enabled_sensor_and_excluded_routes_will_check_test(self):
        sensor = DatabaseSensor({"enabled": True, "exclude_routes": ["1", "10", "20"]})
        self.assertFalse(sensor.should_check("1"))
        self.assertTrue(sensor.should_check(None))

    def with_disabled_sensor_check_test(self):
        sensor = DatabaseSensor({"enabled": False, "large_result": {"limit": 1024}})
        appsensor_meta = AppSensorMeta()
        appsensor_meta.remote_address = "remote_addr"
        appsensor_meta.method = "request_method"
        appsensor_meta.location = "abosolute_uri"
        appsensor_meta.route_id = "route_id"
        appsensor_meta.session_id = "session_id"
        appsensor_meta.user_id = "user_id"

        with patch('tcell_agent.appsensor.sensors.database_sensor.send_event') as patched_send_event:
            sensor.check(appsensor_meta, 3072)
            self.assertFalse(patched_send_event.called)

    def with_enabled_sensor_and_number_of_records_is_too_big_but_route_id_is_excluded_check_test(self):
        sensor = DatabaseSensor({"enabled": True, "large_result": {"limit": 1024}, "exclude_routes": ["23947"]})
        appsensor_meta = AppSensorMeta()
        appsensor_meta.remote_address = "remote_addr"
        appsensor_meta.method = "request_method"
        appsensor_meta.location = "abosolute_uri"
        appsensor_meta.route_id = "23947"
        appsensor_meta.session_id = "session_id"
        appsensor_meta.user_id = "user_id"

        with patch('tcell_agent.appsensor.sensors.database_sensor.send_event') as patched_send_event:
            sensor.check(appsensor_meta, 2048)
            self.assertFalse(patched_send_event.called)

    def with_enabled_sensor_and_number_of_records_is_ok_check_test(self):
        sensor = DatabaseSensor({"enabled": True, "large_result": {"limit": 1024}})
        appsensor_meta = AppSensorMeta()
        appsensor_meta.remote_address = "remote_addr"
        appsensor_meta.method = "request_method"
        appsensor_meta.location = "abosolute_uri"
        appsensor_meta.route_id = "route_id"
        appsensor_meta.session_id = "session_id"
        appsensor_meta.user_id = "user_id"

        with patch('tcell_agent.appsensor.sensors.database_sensor.send_event') as patched_send_event:
            sensor.check(appsensor_meta, 10)
            self.assertFalse(patched_send_event.called)

    def with_enabled_sensor_and_number_of_records_is_too_big_check_test(self):
        appsensor_meta = AppSensorMeta()
        appsensor_meta.remote_address = "remote_addr"
        appsensor_meta.method = "request_method"
        appsensor_meta.location = "abosolute_uri"
        appsensor_meta.route_id = "route_id"
        appsensor_meta.session_id = "session_id"
        appsensor_meta.user_id = "user_id"

        sensor = DatabaseSensor({"enabled": True, "large_result": {"limit": 1024}})

        with patch('tcell_agent.appsensor.sensors.database_sensor.send_event') as patched_send_event:
            sensor.check(appsensor_meta, 3072)
            patched_send_event.assert_called_once_with(
                appsensor_meta=appsensor_meta,
                detection_point=DatabaseSensor.DP_CODE,
                parameter=None,
                meta={"rows": 3072},
                collect_full_uri=False)
